@@ -18,9 +18,19 @@ from novaclient.exceptions import ClientException
 from googleapiclient.errors import Error as GcloudApiError
 from googleapiclient.errors import HttpError as GcloudApiHttpError
 
-from .common import (b, get_xblock_settings,
-                     DELETED_STATE, DELETE_IN_PROGRESS_STATE,
-                     RESUME_STATE, RESUME_IN_PROGRESS_STATE)
+from .common import (
+    b,
+    get_xblock_settings,
+    IN_PROGRESS,
+    FAILED,
+    CREATE_COMPLETE,
+    DELETE_COMPLETE,
+    DELETE_IN_PROGRESS,
+    RESUME_COMPLETE,
+    RESUME_IN_PROGRESS,
+    SUSPEND_COMPLETE,
+    SUSPEND_IN_PROGRESS
+)
 from .openstack import HeatWrapper, NovaWrapper
 from .gcloud import GcloudDeploymentManager, GcloudComputeEngine
 
@@ -45,8 +55,7 @@ class Provider(object):
     @staticmethod
     def init(name):
         settings = get_xblock_settings()
-        task_timeouts = settings.get('task_timeouts', {})
-        sleep_seconds = task_timeouts.get('sleep', 5)
+        sleep_seconds = settings.get("sleep_timeout", 10)
         providers = settings.get("providers")
         config = providers.get(name)
         if config and isinstance(config, dict):
@@ -205,7 +214,7 @@ class OpenstackProvider(Provider):
         try:
             heat_stack = self.heat_c.stacks.get(stack_id=name)
         except HTTPNotFound:
-            status = DELETED_STATE
+            status = DELETE_COMPLETE
             outputs = {}
         except (HTTPException, HttpError) as e:
             raise ProviderException(e)
@@ -244,7 +253,7 @@ class OpenstackProvider(Provider):
         status = heat_stack.stack_status
 
         # Wait for stack creation
-        while 'IN_PROGRESS' in status:
+        while IN_PROGRESS in status:
             self.sleep()
 
             try:
@@ -256,7 +265,7 @@ class OpenstackProvider(Provider):
 
             status = heat_stack.stack_status
 
-        if 'FAILED' in status:
+        if FAILED in status:
             raise ProviderException("Failure creating stack.")
 
         return {"status": status,
@@ -268,11 +277,11 @@ class OpenstackProvider(Provider):
         except (HTTPException, HttpError) as e:
             raise ProviderException(e)
 
-        status = RESUME_IN_PROGRESS_STATE
+        status = RESUME_IN_PROGRESS
 
         # Wait until resume finishes.
-        while ('FAILED' not in status and
-               status != RESUME_STATE):
+        while (FAILED not in status and
+               status != RESUME_COMPLETE):
             self.sleep()
 
             try:
@@ -285,7 +294,7 @@ class OpenstackProvider(Provider):
             else:
                 status = heat_stack.stack_status
 
-        if 'FAILED' in status:
+        if FAILED in status:
             raise ProviderException("Failure resuming stack")
 
         outputs = self._get_stack_outputs(heat_stack)
@@ -303,55 +312,61 @@ class OpenstackProvider(Provider):
         return {"status": status,
                 "outputs": outputs}
 
-    def suspend_stack(self, name):
-        stack = self.get_stack(name)
-
-        # Heat fails to suspend a stack when any of its servers are being
-        # rebooted, so let's try and prevent this.
-        reboot_on_resume = stack["outputs"].get("reboot_on_resume")
-        if (reboot_on_resume is not None and
-                isinstance(reboot_on_resume, list)):
-            for server in reboot_on_resume:
-                try:
-                    nova_server = self.nova_c.servers.get(server)
-                except ClientException as e:
-                    raise ProviderException(e)
-
-                task_state = getattr(nova_server, 'OS-EXT-STS:task_state')
-                if task_state == 'rebooting_hard':
-                    raise ProviderException("Cannot suspend stack with "
-                                            "a rebooting server.")
-
+    def suspend_stack(self, name, wait=True):
         try:
             self.heat_c.actions.suspend(stack_id=name)
         except (HTTPException, HttpError) as e:
             raise ProviderException(e)
 
+        status = SUSPEND_IN_PROGRESS
+
+        # Wait until suspend finishes.
+        if wait:
+            while (FAILED not in status and
+                   status != DELETE_COMPLETE and
+                   status != SUSPEND_COMPLETE):
+                self.sleep()
+
+                try:
+                    heat_stack = self.heat_c.stacks.get(
+                        stack_id=name)
+                except HTTPNotFound:
+                    status = DELETE_COMPLETE
+                except (HTTPException, HttpError) as e:
+                    raise ProviderException(e)
+                else:
+                    status = heat_stack.stack_status
+
+            if FAILED in status:
+                raise ProviderException("Failure suspending stack.")
+
+        return {"status": status}
+
     def delete_stack(self, name, wait=True):
         try:
             self.heat_c.stacks.delete(stack_id=name)
         except (HTTPException, HttpError) as e:
             raise ProviderException(e)
 
-        status = DELETE_IN_PROGRESS_STATE
+        status = DELETE_IN_PROGRESS
 
         # Wait until delete finishes.
         if wait:
-            while ('FAILED' not in status and
-                   status != DELETED_STATE):
+            while (FAILED not in status and
+                   status != DELETE_COMPLETE):
                 self.sleep()
 
                 try:
                     heat_stack = self.heat_c.stacks.get(
                         stack_id=name)
                 except HTTPNotFound:
-                    status = DELETED_STATE
+                    status = DELETE_COMPLETE
                 except (HTTPException, HttpError) as e:
                     raise ProviderException(e)
                 else:
                     status = heat_stack.stack_status
 
-            if 'FAILED' in status:
+            if FAILED in status:
                 raise ProviderException("Failure deleting stack.")
 
         return {"status": status}
@@ -494,22 +509,22 @@ class GcloudProvider(Provider):
         if opstatus == "DONE":
             opstatus = "COMPLETE"
         elif opstatus == "PENDING" or opstatus == "RUNNING":
-            opstatus = "IN_PROGRESS"
+            opstatus = IN_PROGRESS
         else:
             raise ProviderException("Unknown operation status %s" % opstatus)
 
         status = "%s_%s" % (optype, opstatus)
 
         # Calculate suspend status
-        if status == "CREATE_COMPLETE":
+        if status == CREATE_COMPLETE:
             servers = self._get_deployment_servers(deployment_name)
             if servers:
                 if any(s.get("status") == "STOPPING" for s in servers):
-                    status = "SUSPEND_IN_PROGRESS"
+                    status = SUSPEND_IN_PROGRESS
                 elif any(s.get("status") == "STAGING" for s in servers):
-                    status = "RESUME_IN_PROGRESS"
+                    status = RESUME_IN_PROGRESS
                 elif all(s.get("status") == "TERMINATED" for s in servers):
-                    status = "SUSPEND_COMPLETE"
+                    status = SUSPEND_COMPLETE
 
         return status
 
@@ -563,7 +578,7 @@ class GcloudProvider(Provider):
             ).execute()
         except GcloudApiHttpError as e:
             if e.resp.status == 404:
-                status = DELETED_STATE
+                status = DELETE_COMPLETE
                 outputs = {}
             else:
                 raise ProviderException(e)
@@ -677,7 +692,7 @@ class GcloudProvider(Provider):
         except GcloudApiError as e:
             raise ProviderException(e)
 
-        status = DELETE_IN_PROGRESS_STATE
+        status = DELETE_IN_PROGRESS
 
         # Wait until delete finishes.
         if wait:
@@ -697,11 +712,11 @@ class GcloudProvider(Provider):
                                 message = "Error in operation."
                             raise ProviderException(message)
 
-                        status = DELETED_STATE
+                        status = DELETE_COMPLETE
                         break
                 except GcloudApiHttpError as e:
                     if e.resp.status == 404:
-                        status = DELETED_STATE
+                        status = DELETE_COMPLETE
                         break
                     else:
                         raise ProviderException(e)
@@ -712,7 +727,7 @@ class GcloudProvider(Provider):
 
         return {"status": status}
 
-    def suspend_stack(self, name):
+    def suspend_stack(self, name, wait=True):
         deployment_name = self._encode_name(name)
 
         # Get servers
@@ -735,6 +750,19 @@ class GcloudProvider(Provider):
                                         " %s" % (server["name"],
                                                  server["status"]))
 
+        status = SUSPEND_IN_PROGRESS
+
+        # Wait until suspend finishes.
+        if wait:
+            while True:
+                self.sleep()
+                servers = self._get_deployment_servers(deployment_name)
+                if all(s.get("status") == "TERMINATED" for s in servers):
+                    status = SUSPEND_COMPLETE
+                    break
+
+        return {"status": status}
+
     def resume_stack(self, name):
         deployment_name = self._encode_name(name)
 
